#ifndef __MDFN_PSX_INPUT_GUNCON_H
#define __MDFN_PSX_INPUT_GUNCON_H

namespace MDFN_IEN_PSX
{

InputDevice *Device_GunCon_Create(void);
extern IDIISG Device_GunCon_IDII;

}
#endif
